And

Struct And 

pub struct And<LHS, RHS> { /* private fields */ }
AND combinator for two inspections that returns Stop::Yes if both inspections return Stop::Yes.

An inspection is any implementation of the Inspect trait.

The combinator always calls both inspections even if the first inspection results in a stop indicator that will not change due to the result of the second inspection.

Implementations

Source

impl<LHS, RHS> And<LHS, RHS>

pub fn new(lhs: LHS, rhs: RHS) -> Self

Constructs a new And combinator inspection out of the two given inspections.

pub fn unwrap(self) -> (LHS, RHS)

Deconstructs this inspection into its two containing inspections.

pub fn left(&self) -> &LHS

Returns a reference to the left inspection.

pub fn right(&self) -> &RHS

Returns a reference to the right inspection.