Limit

Struct Limit 

pub struct Limit { /* private fields */ }
Limits the number of steps a reduction or evaluation function performs until processing is stopped.

This inspection counts each call to the Inspect::inspect function. If the number of calls counted so far is less than the limit for which the Limit has been constructed it returns Stop::No to continue processing. If the limit has been reached it returns Stop::Yes to instruct the evaluation or reduction function to stop processing.

A limit of 0 means that not reduction will be performed at all.

Examples

let mut term = app(
    lam("a", app(var("a"), var("a"))),
    lam("a", app(var("a"), var("a"))),
);

term.reduce_inspected::<NormalOrder<Enumerate>, _>(&mut Limit::new(5));

Implementations

Source

impl Limit

pub fn new(limit: u32) -> Self

Constructs a new Limit inspection with the given number of steps as the limit of reduction or evaluation steps.

pub fn limit(&self) -> u32

The limit for the number steps.

pub fn count(&self) -> u32

The number of steps counted so far.