pub struct ParseError { /* private fields */ }Expand description
An error that occurs during parsing of expressions.
Implementations
Sourceimpl ParseError
impl ParseError
Sourcepub fn new(
kind: ParseErrorKind,
position: CharPosition,
found: impl Display,
expected: impl Display,
hint: Option<Hint>,
) -> Self
pub fn new( kind: ParseErrorKind, position: CharPosition, found: impl Display, expected: impl Display, hint: Option<Hint>, ) -> Self
Constructs a new ParseError with the given information.
Sourcepub fn kind(&self) -> ParseErrorKind
pub fn kind(&self) -> ParseErrorKind
Returns the kind of error that has been found.
Sourcepub fn position(&self) -> CharPosition
pub fn position(&self) -> CharPosition
Returns the position in the input stream, where the error has been found.