pub struct And<LHS, RHS> { /* private fields */ }Expand description
AND combinator for two inspections that returns Stop::Yes if both
inspections return Stop::Yes.
An inspection is any implementation of the Inspect trait.
The combinator always calls both inspections even if the first inspection results in a stop indicator that will not change due to the result of the second inspection.
Implementations